from .functions import Querys


def get_url(headers, db):
    """Check the appoimentID from the url
    Match with the database to validate if exist

    Args:
        headers ([type]): [Headers Objec]

    Returns:
        url [string]: [url validate]
    """

    try:
        url_origin = headers.get("Origin", False)
        appointment_id = url_origin.split("-")[2]
        query_functions = Querys(appointment_id)
        query, job_config = query_functions.from_telehealth_room_url()
        df = db.query(query, job_config=job_config).to_dataframe()
        url = df.url[0] if not df.empty else ""
    except IndexError:
        url = ""
    except AttributeError:
        url = ""

    return url



from setuptools import setup, find_packages

classifiers = [
    "Development Status :: 5 - Production/Stable",
    "Intended Audience :: Education",
    "Operating System :: Microsoft :: Windows :: Windows 10",
    "License :: OSI Approved :: MIT License",
    "Programming Language :: Python :: 3",
]

setup(
    name="getDynamicUrl",
    version="0.0.4",
    description="Get dyanmic Url",
    long_description=open("README.txt").read()
    + "\n\n"
    + open("CHANGELOG.txt").read(),
    url="",
    author="Jhone Mendez",
    author_email="jhone0901@gmail.com",
    license="MIT",
    classifiers=classifiers,
    keywords="dynamicUrl",
    packages=find_packages(),
    install_requires=["google-cloud-bigquery", "pyarrow"],
)
